@@ -24,6 +24,7 @@ options::options(QWidget *parent) :
                  }
 
                  load_cfg();
+
 }
 
 options::~options()
@@ -58,8 +59,8 @@ void options::load_cfg(){
     configs<<"psx4m-cycle"<<"psx4m-frame"<<"psx4m-hwa"<<"psx4m-fps"<<"psx4m-fullscreen"<<"psx4m-afix";
     configs<<"pcsx-threadedspu"<<"pcsx-hwa"<<"pcsx-bios"<<"pcsx-frameskip";
     configs<<"accel";
-    configs<<"cdda" <<    "xa" <<    "rcnt"<<    "sio"<<    "spuir"<<    "vsync";
-    configs<<"fsaa";
+    configs<<"cdda" <<    "xa" <<    "rcnt"<<    "sio"<<    "spuirq"<<    "vsync";
+    configs<<"fsaa"<<"pcsx-fullscreen";
 
     if (QFile::exists(path)){
 
@@ -81,7 +82,7 @@ void options::load_cfg(){
                      if (value=="1")ui->checkBox->setChecked(true);else ui->checkBox->setChecked(false);
                      break;
                  case 2: // bios
-                     value="scph1001.bin";
+if (value=="")value="scph1001.bin";
                      if (ui->comboBox_4->findText(value)!=1)
                          ui->comboBox_4->setCurrentIndex(ui->comboBox_4->findText(value));
                          break;
@@ -142,7 +143,9 @@ void options::load_cfg(){
                  case 20:
                       if (value=="1")ui->checkBox_16->setChecked(true);else ui->checkBox_16->setChecked(false);
                       break;
-
+                 case 21:
+                      if (value=="1")ui->checkBox_17->setChecked(true);else ui->checkBox_17->setChecked(false);
+                      break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -153,6 +156,8 @@ void options::load_cfg(){
              // checking
              psx4m_hwa_block();
 
+             if (!ui->comboBox_4->currentIndex()>-1)ui->comboBox_4->setCurrentIndex(0);
+
              createCfg();
     }
 }
@@ -163,11 +168,11 @@ void options::createCfg(){
     if (ui->checkBox->isChecked())current_config<<"-nosound";
     if (ui->checkBox_9->isChecked())current_config<<"-accel";
 
-    if (ui->checkBox_10->isChecked())current_config<<"-cdda";
-    if (ui->checkBox_11->isChecked())current_config<<"-xa";
-    if (ui->checkBox_12->isChecked())current_config<<"-rcnt";
-    if (ui->checkBox_13->isChecked())current_config<<"-sio";
-    if (ui->checkBox_14->isChecked())current_config<<"-spuirq";
+    if (ui->checkBox_10->isChecked())current_config<<"-xa";
+    if (ui->checkBox_11->isChecked())current_config<<"-cdda";
+    if (ui->checkBox_12->isChecked())current_config<<"-sio";
+    if (ui->checkBox_13->isChecked())current_config<<"-spuirq";
+    if (ui->checkBox_14->isChecked())current_config<<"-rcnt";
     if (ui->checkBox_15->isChecked())current_config<<"-vsync";
 
     if (ui->radioButton_2->isChecked())
@@ -176,9 +181,13 @@ void options::createCfg(){
 
         if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
         if (ui->checkBox_4->isChecked())current_config<<"-gles";
-        if (ui->checkBox_5->isChecked())current_config<<"-bios"<<ui->comboBox_4->currentText()<<"-bdir"<<bios_path;;
+
+        if (ui->checkBox_5->isChecked())
+            if (!ui->comboBox_4->currentText().isEmpty() && !bios_path.isEmpty())
+                      current_config<<"-bios"<<ui->comboBox_4->currentText()<<"-bdir"<<bios_path;
         if (ui->comboBox_3->currentIndex()>0)
         current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
+        if (ui->checkBox_17->isChecked())current_config<<"-fullscreen";
         current_config<<"-cdfile";
 
     }
@@ -237,7 +246,8 @@ void options::save_cfg(){
                    "sio=%18\n" \
                    "spuirq=%19\n" \
                    "vsync=%20\n" \
-                   "fsaa=%21\n")
+                   "fsaa=%21\n" \
+                   "pcsx-fullscreen=%22\n" )
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -259,6 +269,7 @@ void options::save_cfg(){
 .arg(ui->checkBox_14->isChecked()?"1":"0")
 .arg(ui->checkBox_15->isChecked()?"1":"0")
         .arg(ui->checkBox_16->isChecked()?"1":"0")
+        .arg(ui->checkBox_17->isChecked()?"1":"0")
 
 ;
 
